@@ -257,7 +257,7 @@ makeRweaveAsciidocCodeRunner <- function(evalFunc=RweaveEvalWithOpt)
              close(chunkout)
 
           if(options$split & options$include){
-              cat("include::", chunkprefix, "\n", sep="",
+              cat("include::", chunkprefix, ".txt[]\n", sep="",
                 file=object$output, append=TRUE)
               linesout[thisline + 1L] <- srcline
               thisline <- thisline + 1L
